@@ -1,12 +1,12 @@
 from ._mapi import *
 from ._node import *
 from ._group import _add_elem_2_stGroup
-from ._group import _add_node_2_stGroup,Group
+from ._group import _add_node_2_stGroup,Group,nodesInGroup
 import numpy as np
 from scipy.interpolate import splev, splprep , interp1d , Akima1DInterpolator
 from math import hypot
 import math
-from ._utils import _convItem2List
+from ._utils import _convItem2List , _longestList
 
 def _SInterp(angle,num_points):
     ''' Angle -> Input list | Num Points -> Output length'''
@@ -35,7 +35,7 @@ def _SInterp(angle,num_points):
 
     return angle_intrp_finalY
 
-def _interpolateAlignment(pointsArray,n_seg=10,deg=1,mSize=0,includePoint:bool=True) -> list:
+def _interpolateAlignment(pointsArray,n_seg=10,deg=1,mSize=0,includePoint:bool=True,div_axis="L") -> list:
     ''' Returns point list and beta angle list'''
     pointsArray = np.array(pointsArray)
     x_p, y_p , z_p  = pointsArray[:,0] , pointsArray[:,1] , pointsArray[:,2]
@@ -46,13 +46,6 @@ def _interpolateAlignment(pointsArray,n_seg=10,deg=1,mSize=0,includePoint:bool=T
         deg = len(pointsArray)-1
 
     #-- Actual length ----
-    dxq = np.diff(x_p)
-    dyq = np.diff(y_p)
-    dzq = np.diff(z_p)
-    dlq=[0]
-
-    for i in range(len(dxq)):
-        dlq.append(hypot(dxq[i],dyq[i],dzq[i]))
 
     tck, u = splprep([x_p, y_p, z_p], s=0, k=deg)
 
@@ -74,9 +67,19 @@ def _interpolateAlignment(pointsArray,n_seg=10,deg=1,mSize=0,includePoint:bool=T
         n_seg=int(total_l/mSize)
 
 
-    eq_len = np.linspace(0,total_l,n_seg+1)
+    if div_axis == "X":
+        eq_x = np.linspace(x_p[0],x_p[-1],n_seg+1)
+        interp_u = np.interp(eq_x,x_den,u_fine)
+    elif div_axis == "Y":
+        eq_y = np.linspace(y_p[0],y_p[-1],n_seg+1)
+        interp_u = np.interp(eq_y,y_den,u_fine)
+    elif div_axis == "Z":
+        eq_z = np.linspace(z_p[0],z_p[-1],n_seg+1)
+        interp_u = np.interp(eq_z,z_den,u_fine)
+    else :
+        eq_len = np.linspace(0,total_l,n_seg+1)
+        interp_u = np.interp(eq_len,cum_l,u_fine)
 
-    interp_u = np.interp(eq_len,cum_l,u_fine)
 
     if includePoint:
         interp_u = np.sort(np.append(interp_u,u[1:-1])).tolist()
@@ -206,39 +209,50 @@ def _ADD(self):
     """
 
     # ------------  ID assignment -----------------------
-    id = int(self.ID)
-    if not Element.ids:
-        count = 1
-    else:
-        count = max(Element.ids) + 1
+    if NX.onlyNode == False :
+        id = int(self.ID)
+        if not Element.ids:
+            count = 1
+        else:
+            count = max(Element.ids) + 1
 
-    if id == 0:
-        self.ID = count
-        Element.elements.append(self)
-        Element.ids.append(int(self.ID))
-    elif id in Element.ids:
-        self.ID = int(id)
-        print(f'⚠️  Element with ID {id} already exists! It will be replaced.')
-        index = Element.ids.index(id)
-        Element.elements[index] = self
-    else:
-        self.ID = id
-        Element.elements.append(self)
-        Element.ids.append(int(self.ID))
-    Element.__elemDIC__[str(self.ID)] = self
-    
-    # ------------  Group assignment -----------------------
-    if self._GROUP == "" :
-        pass
-    elif isinstance(self._GROUP, list):
-        for gpName in self._GROUP:
-            _add_elem_2_stGroup(self.ID,gpName)
+        if id == 0:
+            self.ID = count
+            Element.elements.append(self)
+            Element.ids.append(int(self.ID))
+        elif id in Element.ids:
+            self.ID = int(id)
+            print(f'⚠️  Element with ID {id} already exists! It will be replaced.')
+            index = Element.ids.index(id)
+            Element.elements[index] = self
+        else:
+            self.ID = id
+            Element.elements.append(self)
+            Element.ids.append(int(self.ID))
+        Element.__elemDIC__[str(self.ID)] = self
+        
+        # ------------  Group assignment -----------------------
+        if self._GROUP == "" :
+            pass
+        elif isinstance(self._GROUP, list):
+            for gpName in self._GROUP:
+                _add_elem_2_stGroup(self.ID,gpName)
+                for nd in self.NODE:
+                    _add_node_2_stGroup(nd,gpName)
+        elif isinstance(self._GROUP, str):
+            _add_elem_2_stGroup(self.ID,self._GROUP)
             for nd in self.NODE:
-                _add_node_2_stGroup(nd,gpName)
-    elif isinstance(self._GROUP, str):
-        _add_elem_2_stGroup(self.ID,self._GROUP)
-        for nd in self.NODE:
-            _add_node_2_stGroup(nd,self._GROUP)
+                _add_node_2_stGroup(nd,self._GROUP)
+    else:
+        if self._GROUP == "" :
+            pass
+        elif isinstance(self._GROUP, list):
+            for gpName in self._GROUP:
+                for nd in self.NODE:
+                    _add_node_2_stGroup(nd,gpName)
+        elif isinstance(self._GROUP, str):
+            for nd in self.NODE:
+                _add_node_2_stGroup(nd,self._GROUP)
             
 
 
@@ -382,9 +396,7 @@ class Element:
     @staticmethod
     def delete():
         MidasAPI("DELETE", "/db/ELEM")
-        Element.elements = []
-        Element.ids = []
-        Element.__elemDIC__={}
+        Element.clear()
     
     @staticmethod
     def clear():
@@ -408,6 +420,7 @@ class Element:
                 angle: Beta angle for section orientation in degrees (default 0.0)
                 group: Structure group of the element (str or list; 'SG1' or ['SG1','SG2'])
                 id: Element ID (default 0 for auto-increment)
+                
             
             Examples:
                 ```python
@@ -495,7 +508,7 @@ class Element:
                 return beam_obj
         
         @staticmethod
-        def PLine(points_loc:list,n_div:int=0,deg:int=1,includePoint:bool=True,mat:int=1,sect:int=1,angle:float=0, group = "" , id: int = 0,bLocalAxis=False):
+        def PLine(points_loc:list,n_div:int=0,deg:int=1,includePoint:bool=False,mat:int=1,sect:int=1,angle:float=0, group = "" , id: int = 0,bLocalAxis=False,div_axis="L"):
                 '''
                 angle : float of list(float)
                 '''
@@ -505,7 +518,7 @@ class Element:
                 if n_div == 0 :
                     i_loc = points_loc
                 else:
-                    i_loc = _interpolateAlignment(points_loc,n_div,deg,0,includePoint)
+                    i_loc = _interpolateAlignment(points_loc,n_div,deg,0,includePoint,div_axis)
 
                 num_points = len(i_loc)                
                 angle_intrp_finalY = _SInterp(angle,num_points-1) #Beta Angle to be applied to Elements So, n-1
@@ -521,7 +534,7 @@ class Element:
                 return beam_obj
         
         @staticmethod
-        def PLine2(points_loc:list,n_div:int=0,deg:int=1,includePoint:bool=True,mat:int=1,sect:int=1,angle:list[float]=0, group = "" , id: int = 0,bLocalAxis=False,yEcc:list[float]=0,zEcc:list[float]=0,bAngleInEcc:bool=True):
+        def PLine2(points_loc:list,n_div:int=0,deg:int=1,includePoint:bool=False,mat:int=1,sect:int=1,angle:list[float]=0, group = "" , id: int = 0,bLocalAxis=False,div_axis="L",yEcc:list[float]=0,zEcc:list[float]=0,bAngleInEcc:bool=True):
                 '''
                 Creates a polyline with Eccentricity considering the beta angle provided   
                 angle , yEcc , zEcc : float or list(float)   
@@ -536,7 +549,7 @@ class Element:
                 if n_div == 0 :
                     i_loc = points_loc
                 else:
-                    i_loc = _interpolateAlignment(points_loc,n_div,deg,0,includePoint)
+                    i_loc = _interpolateAlignment(points_loc,n_div,deg,0,includePoint,div_axis)
                 
                 
                 num_points = len(i_loc)                
@@ -675,22 +688,59 @@ class Element:
             self.TYPE = 'PLATE'
             self.MATL = mat
             self.SECT = sect
-            self.NODE = nodes
+            
             self.ANGLE = angle
             self.STYPE = stype
             self._GROUP = group
 
-            if len(nodes)==3:
-                self.AREA,self.NORMAL = _triangleAREA(nodeByID(nodes[0]),nodeByID(nodes[1]),nodeByID(nodes[2]))
-            elif len(nodes)==4:
+            uniq_nodes = list(dict.fromkeys(nodes))
+            self._NPOINT=len(uniq_nodes)
+            if len(uniq_nodes)==3:
+                self.NODE = uniq_nodes
+                self.AREA,self.NORMAL = _triangleAREA(nodeByID(uniq_nodes[0]),nodeByID(uniq_nodes[1]),nodeByID(uniq_nodes[2]))
+            elif len(uniq_nodes)==4:
+                self.NODE = nodes
                 a1 , n1 = _triangleAREA(nodeByID(nodes[0]),nodeByID(nodes[1]),nodeByID(nodes[2]))
                 a2 , n2 = _triangleAREA(nodeByID(nodes[2]),nodeByID(nodes[3]),nodeByID(nodes[0]))
                 self.AREA = a1+a2
-                self.NORMAL = (n1+n2)/np.linalg.norm((n1+n2))
+                self.NORMAL = (n1+n2)/np.linalg.norm((n1+n2+0.000001))
                 
 
 
             _ADD(self)
+
+        # @staticmethod
+        # def fromPoints(points: list, meshSize:float=0, stype: int = 1, mat: int = 1, sect: int = 1, angle: float = 0, group = "" , id: int = 0): #CHANGE TO TUPLE
+        #         # INPUTS POINTS and create a triangular meshing with given mesh size  |  If meshSize = 0 , half of shortest length will be taken as mesh size
+        #         return 0
+        
+        @staticmethod
+        def loftGroups(strGroups: list, stype: int = 1, mat: int = 1, sect: int = 1, angle: float = 0, group = "" , id: int = 0): #CHANGE TO TUPLE
+                # INPUTS 2 or more structure groups to create rectangular plates between the nodes | No. of nodes should be same in the Str Group
+            """
+            INPUTS 2 or more structure groups to create rectangular plates between the nodes  
+            No. of nodes should be same in the Str Group
+            """
+            n_groups = len(strGroups)
+            if n_groups < 2 :
+                print("⚠️ No. of structure groups in Plate.loftGroups in less than 2")
+                return False
+            plate_obj = []
+            for ng in range(n_groups-1):
+                nID_A = nodesInGroup(strGroups[ng])   
+                nID_B = nodesInGroup(strGroups[ng+1])
+
+                max_len = max(len(nID_A),len(nID_B))
+                if max_len < 2 :
+                    print("⚠️ No. of nodes in Plate.loftGroups in less than 2")
+                    return False
+
+                nID_A , nID_B = _longestList(nID_A , nID_B)
+                for i in range(max_len-1):
+                    pt_array = [nID_A[i],nID_B[i],nID_B[i+1],nID_A[i+1]]
+                    plate_obj.append(Element.Plate(pt_array,stype,mat,sect,angle,group,id))
+
+            return plate_obj
             
     class Tension(_common):
      def __init__(self, i: int, j: int, stype: int, mat: int = 1, sect: int = 1, angle: float = 0, group = "" , id: int = 0, non_len: float = None, cable_type: int = None, tens: float = None, t_limit: float = None):
