@@ -1,7 +1,7 @@
 from ._mapi import *
 from ._model import *
 from ._group import *
-
+import numpy as np
 
 
 # -----  Extend for list of nodes/elems -----
@@ -28,6 +28,8 @@ def _ADD_BeamLoad(self):
 class Load_Case:
     """Type symbol (Refer Static Load Case section in the Onine API Manual, Load Case names.  
     \nSample: Load_Case("USER", "Case 1", "Case 2", ..., "Case n")"""
+    maxID = 0
+    maxNO = 0
     cases = []
     types = ["USER", "D", "DC", "DW", "DD", "EP", "EANN", "EANC", "EAMN", "EAMC", "EPNN", "EPNC", "EPMN", "EPMC", "EH", "EV", "ES", "EL", "LS", "LSC", 
             "L", "LC", "LP", "IL", "ILP", "CF", "BRK", "BK", "CRL", "PS", "B", "WP", "FP", "SF", "WPR", "W", "WL", "STL", "CR", "SH", "T", "TPG", "CO",
@@ -36,10 +38,17 @@ class Load_Case:
         self.TYPE = type
         self.NAME = name
         self.ID = []
+        self.NO = []
         for i in range(len(self.NAME)):
-            if Load_Case.cases == []: self.ID.append(i+1)
-            if Load_Case.cases != []: self.ID.append(max(Load_Case.cases[-1].ID) + i + 1)
+            if Load_Case.cases == []: 
+                self.ID.append(i+1)
+                self.NO.append(i+1)
+            if Load_Case.cases != []: 
+                self.ID.append(Load_Case.maxID + i + 1)
+                self.NO.append(Load_Case.maxNO + i + 1)
         Load_Case.cases.append(self)
+        Load_Case.maxID = max(max(self.ID),Load_Case.maxID)
+        Load_Case.maxNO = max(max(self.NO),Load_Case.maxNO)
     
     @classmethod
     def json(cls):
@@ -49,6 +58,7 @@ class Load_Case:
             if i.TYPE in cls.types:
                 for j in i.ID:
                     json['Assign'][j] = {
+                        "NO": i.NO[i.ID.index(j)],
                         "NAME": i.NAME[i.ID.index(j)],
                         "TYPE": i.TYPE}
             else:
@@ -66,17 +76,30 @@ class Load_Case:
     
     @staticmethod
     def sync():
+        Load_Case.maxID = 0
+        Load_Case.maxNO = 0
         a = Load_Case.get()
         if a != {'message': ''}:
             if list(a['STLD'].keys()) != []:
                 Load_Case.cases = []
                 for j in a['STLD'].keys():
-                    Load_Case(a['STLD'][j]['TYPE'], a['STLD'][j]['NAME'])
+                    lc = Load_Case(a['STLD'][j]['TYPE'], a['STLD'][j]['NAME'])
+                    lcID = int(j)
+                    lCNO = int(a['STLD'][j]['NO'])
+                    lc.ID = [lcID]
+                    lc.NO = [lCNO]
+
+                    Load_Case.maxID = max(Load_Case.maxID ,lcID )
+                    Load_Case.maxNO = max(Load_Case.maxNO ,lCNO )
     
     @classmethod
     def delete(cls):
-        cls.cases=[]
+        cls.clear()
         return MidasAPI("DELETE","/db/stld")
+    
+    @classmethod
+    def clear(cls):
+        cls.cases=[]
 #---------------------------------------------------------------------------------------------------------------
 
 
@@ -89,7 +112,13 @@ class Load:
         if cls.SW.data!=[]: cls.SW.create()
         if cls.Nodal.data!=[]: cls.Nodal.create()
         if cls.Beam.data!=[]: cls.Beam.create()
-        
+    
+    @classmethod
+    def clear(cls):
+        Load_Case.clear()
+        cls.SW.clear()
+        cls.Nodal.clear()
+        cls.Beam.clear()
 
     class SW:
         """Load Case Name, direction, Value, Load Group.\n
@@ -148,8 +177,12 @@ class Load:
         
         @classmethod
         def delete(cls):
-            cls.data=[]
+            cls.clear()
             return MidasAPI("DELETE","/db/BODF")
+
+        @classmethod
+        def clear(cls):
+            cls.data=[]
         
         @staticmethod
         def sync():
@@ -235,9 +268,13 @@ class Load:
         
         @classmethod
         def delete(cls):
-            cls.data=[]
+            cls.clear()
             return MidasAPI("DELETE", "/db/CNLD")
         
+        @classmethod
+        def clear(cls):
+            cls.data=[]
+        
         @classmethod
         def sync(cls):
             cls.data = []
@@ -384,9 +421,13 @@ class Load:
         
         @classmethod
         def delete(cls):
-            cls.data=[]
+            cls.clear()
             return MidasAPI("DELETE", "/db/bmld")
         
+        @classmethod
+        def clear(cls):
+            cls.data=[]
+        
         @classmethod
         def sync(cls):
             cls.data = []
