@@ -12,7 +12,11 @@ from ._thickness import *
 
 from ._tendon import *
 from ._result import *
+from ._movingload import *
 
+from ._temperature import *
+
+from collections import defaultdict
 class Model:
 
     #4 Function to check analysis status & perform analysis if not analyzed
@@ -237,7 +241,17 @@ class Model:
     #                 Material.update_class()
 
 
-
+    @staticmethod
+    def maxID(dbNAME:str = 'NODE') -> int :
+        ''' 
+        Returns maximum ID of a DB in CIVIL NX
+        dbNAME - 'NODE' , 'ELEM' , 'THIK' , 'SECT' 
+        If no data exist, 0 is returned
+        '''
+        dbJS = MidasAPI('GET',f'/db/{dbNAME}')
+        if dbJS == {'message': ''}:
+            return 0
+        return max(map(int, list(dbJS[dbNAME].keys())))
 
     @staticmethod
     def create():
@@ -251,10 +265,12 @@ class Model:
         Group.create()
         Boundary.create()
         Load.create()
+        Temperature.create()
         Tendon.create()
         if Section.TaperedGroup.data !=[] : Section.TaperedGroup.create()
-
+        MovingLoad.create()
         LoadCombination.create()
+        
 
 
 
@@ -262,13 +278,21 @@ class Model:
 
     @staticmethod
     def clear():
-        Node.delete()
-        Element.delete()
-        Load_Case.delete()
-        Group.delete()
-        Material.deleteAll()
-        Section.delete()
-        Boundary.delete()
+        Material.clearAll()
+        Section.clear()
+        Thickness.clear()
+        Node.clear()
+        Element.clear()
+        NodeLocalAxis.clear()
+        Group.clear()
+        Boundary.clear()
+        Load.clear()
+        Temperature.clear()
+        Tendon.clear()
+        Section.TaperedGroup.clear()
+        LoadCombination.clear()
+
+
 
     @staticmethod
     def type(strc_type=0,mass_type=1,gravity:float=0,mass_dir=1):
@@ -320,17 +344,29 @@ class Model:
         if location=="":
             MidasAPI("POST","/doc/SAVE",{"Argument":{}})
         else:
-            MidasAPI("POST","/doc/SAVEAS",{"Argument":str(location)})#Dumy location
+            if location.endswith('.mcb') or location.endswith('.mcbz'):
+                MidasAPI("POST","/doc/SAVEAS",{"Argument":str(location)})#Dumy location
+            else:
+                print('⚠️  File extension is missing')
+                
 
     @staticmethod
     def saveAs(location=""):
-        """Saves the model at location provided"""
-        MidasAPI("POST","/doc/SAVEAS",{"Argument":str(location)})
+        """Saves the model at location provided   
+         Model.saveAs("D:\\model2.mcb")"""
+        if location.endswith('.mcb') or location.endswith('.mcbz'):
+            MidasAPI("POST","/doc/SAVEAS",{"Argument":str(location)})
+        else:
+            print('⚠️  File extension is missing')
     
     @staticmethod
     def open(location=""):
         """Open Civil NX model file \n Model.open("D:\\model.mcb")"""
-        MidasAPI("POST","/doc/OPEN",{"Argument":str(location)})
+        if location.endswith('.mcb') or location.endswith('.mcbz'):
+            MidasAPI("POST","/doc/OPEN",{"Argument":str(location)})
+        else:
+            print('⚠️  File extension is missing')
+        
 
     @staticmethod
     def new():
@@ -396,6 +432,43 @@ class Model:
         else:
             print('⚠️  Location data in importMCT is missing file extension')
 
+    @staticmethod
+    def get_element_connectivity():
+        element_connectivity = {}
+        for element in Element.elements:
+            element_id = element.ID
+            connected_nodes = element.NODE
+            element_connectivity.update({element_id: connected_nodes})
+        return element_connectivity
+
+    @staticmethod
+    def get_node_connectivity():
+        element_connectivity = Model.get_element_connectivity()
+        node_connectivity = defaultdict(list)
+
+        for element_id, nodes in element_connectivity.items():
+            for node in nodes:
+                node_connectivity[node].append(element_id)
+        node_connectivity = dict(node_connectivity)
+        return node_connectivity
+
+    @staticmethod
+    def visualise():
+        if NX.visualiser:
+            try:
+                from ._visualise import displayWindow
+                displayWindow()
+            except:
+                pass
+
+    @staticmethod
+    def snap():
+        if NX.visualiser:
+            try:
+                from ._visualise import take_snapshot
+                take_snapshot()
+            except:
+                pass
 
 
 
